@@ -1,13 +1,13 @@
 """
 Core Hyperpython API
 """
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 __author__ = 'Fábio Macêdo Mendes'
 
-# We put all
+# Ugly hack to make it possible to store __version__ directly on __init__.py
 try:
     from .core import Element, Text, Block
-    from .render import render, render_html
+    from .html import html, render
     from .tags import (
         HTML5, h,
         body, head, meta, link, title, div, span, article, aside, details, footer,
@@ -23,7 +23,8 @@ try:
         frame, frameset, noframes, strike, tt
     )
     from .utils import escape, unescape, safe, sanitize
+    from .fragment import fragment
     from .helpers import classes
-except Exception as exc:
+except ImportError as exc:
     print('Caught exception:', exc)
     print('This is expected during installation.')
